This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kubecost.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
kubecost.com/v1alpha1
TurndownSchedule